@@ -8,7 +8,7 @@ from optparse import OptionParser
 from os import getpid
 from sys import stdout, stderr, exit
 from logging import getLogger, info, warning, error
-from ptrace.version import VERSION, WEBSITE
+from ptrace.version import __version__ as VERSION, WEBSITE
 from ptrace.error import PTRACE_ERRORS, writeError
 from ptrace.binding import HAS_PTRACE_SINGLESTEP
 from ptrace.disasm import HAS_DISASSEMBLER
@@ -18,7 +18,7 @@ from ptrace.process_tools import dumpProcessInfo
 from ptrace.tools import inverseDict
 from ptrace.func_call import FunctionCallOptions
 from ptrace.signames import signalName, SIGNAMES
-from ptrace.six import PY3, binary_type
+from six import PY3, binary_type
 from signal import SIGTRAP, SIGINT
 from ptrace.terminal import enableEchoMode, terminalWidth
 from errno import ESRCH
@@ -534,7 +534,7 @@ class Gdb(Application):
             if not key.startswith("$"):
                 return 'Register name (%s) have to start with "$"' % key
             key = key[1:]
-        except ValueError as err:
+        except ValueError:
             return "Invalid command: %r" % command
         try:
             value = self.parseInteger(value)
@@ -594,7 +594,7 @@ class Gdb(Application):
             self.process.waitSignals(SIGTRAP)
             if breakpoint:
                 breakpoint.desinstall(set_ip=True)
-        except:
+        except:   # noqa: E722
             if breakpoint:
                 breakpoint.desinstall()
             raise
